use bevy::prelude::*;

use crate::{player::Player, FISHING_AREA_RADIUS};

#[derive(Debug, Component)]
pub struct Water;

impl Water {
    pub fn setup(mut commands: Commands, asset_server: Res<AssetServer>) {
        let image = asset_server.load::<Image>("water.png");
        let sprite = Sprite::from_image(image);
        commands.spawn((sprite.clone(), Transform::from_xyz(500.0, 0.0, -1.0), Water));
        commands.spawn((sprite, Transform::from_xyz(-500.0, 0.0, -1.0), Water));
    }

    pub fn fishing(
        player_transform_query: Query<&Transform, With<Player>>,
        mut player_query: Query<&mut Player, With<Player>>,
        water_query: Query<&Transform, With<Water>>,
        keyboard: Res<ButtonInput<KeyCode>>,
    ) {
        let player_transform = player_transform_query.get_single().unwrap();
        let mut player = player_query.get_single_mut().unwrap();

        for water_query in &water_query {
            let distance = player_transform
                .translation
                .distance(water_query.translation);

            if distance < FISHING_AREA_RADIUS {
                if keyboard.just_pressed(KeyCode::KeyE) {
                    player.fish_count += 1;
                }
            }
        }
    }
}
